# Super Print

Repositório para estudo de criação e publicação de pacote Python.

## Installation

Use o [pip](https://pip.pypa.io/en/stable/) para instalar o pacote

```bash
pip install super-colored-print
```

## Usage

```python
from super_colored_print import colored_print
colored_print.colored_print("Hello World!", "red")
```

## Author
Victor Stein

## License
[MIT](https://choosealicense.com/licenses/mit/)